TestingApp

Struct TestingApp 

pub struct TestingApp { /* private fields */ }

Implementations

Source

impl TestingApp

pub fn new(app: App) -> Self

Create a new TestingApp wrapping the given application

pub fn config(self, config: TestConfig) -> Self

Set the global test configuration

pub fn test(&self, name: impl Into<String>) -> TestCase

Create a new test case with the given name

Source

impl TestingApp

pub fn execute(&self, test_case: TestCase) -> TestCaseResult

Execute a test case and return the test result

This method parses the arguments, runs the application with a mock context, and validates all assertions.

pub fn execute_spec(&self, spec: &SpecFile) -> TestSuitesResult

Execute all tests in a spec file and return results

This method iterates through all suites and tests in the spec file, converts each test case, executes it, and collects results.